@@ -521,7 +521,8 @@ panel_applet_create_menu (AppletInfo *info)
 
 		/* FIXME: should have a "Move" pixmap.
 		 */
-		setup_menuitem (menuitem, NULL, _("_Move"));
+		image = gtk_image_new ();
+		setup_menuitem (menuitem, image, _("_Move"));
 
 		g_signal_connect (menuitem, "activate",
 				  G_CALLBACK (move_applet_callback), info);
@@ -716,6 +717,7 @@ panel_applet_get_full_gconf_key (AppletType   type,
 }
 
 typedef struct {
+	AppletType   type;
 	PanelWidget *panel_widget;
 	int          position;
 	char        *unique_id;
@@ -739,7 +741,7 @@ whack_applet_to_load (PanelAppletToLoad *applet)
 }
 
 static gboolean
-panel_applet_load_idle_handler (gpointer dummmy)
+panel_applet_load_idle_handler (gpointer dummy)
 {
 	PanelAppletToLoad *applet;
 
@@ -752,10 +754,43 @@ panel_applet_load_idle_handler (gpointer dummmy)
 		g_slist_delete_link (panel_applets_to_load,
 				     panel_applets_to_load);
 
-	panel_applet_frame_load_from_gconf (
-			applet->panel_widget,
-			applet->position,
-			applet->unique_id);
+	switch (applet->type) {
+	case APPLET_BONOBO:
+		panel_applet_frame_load_from_gconf (
+					applet->panel_widget,
+					applet->position,
+					applet->unique_id);
+		break;
+	case APPLET_DRAWER:
+		drawer_load_from_gconf (applet->panel_widget,
+					applet->position,
+					applet->unique_id);
+		break;
+	case APPLET_MENU:
+		menu_load_from_gconf (applet->panel_widget,
+				      applet->position,
+				      applet->unique_id);
+		break;
+	case APPLET_LAUNCHER:
+		launcher_load_from_gconf (applet->panel_widget,
+					  applet->position,
+					  applet->unique_id);
+		break;
+	case APPLET_LOGOUT:
+		load_logout_applet (applet->panel_widget,
+				    applet->position,
+				    TRUE,
+				    applet->unique_id);
+		break;
+	case APPLET_LOCK:
+		load_lock_applet (applet->panel_widget,
+				  applet->position,
+				  TRUE,
+				  applet->unique_id);
+		break;
+	default:
+		break;
+	}
 
 	whack_applet_to_load (applet);
 
@@ -781,13 +816,14 @@ panel_applet_load_from_unique_id (AppletType   type,
 				  const char  *profile,
 				  const char  *unique_id)
 {
-	PanelWidget *panel_widget;
-	AppletType   applet_type;
-	const char  *temp_key;
-	char        *type_string;
-	char        *panel_id;
-	int          position;
-	gboolean     right_stick;
+	PanelAppletToLoad *applet;
+	PanelWidget       *panel_widget;
+	AppletType         applet_type;
+	const char        *temp_key;
+	char              *type_string;
+	char              *panel_id;
+	int                position;
+	gboolean           right_stick;
 
 	temp_key = panel_applet_get_full_gconf_key (
 			type, profile, unique_id, "object_type");
@@ -832,44 +868,18 @@ panel_applet_load_from_unique_id (AppletType   type,
 	if (right_stick)
 		position = panel_widget->size - position;
 
-	switch (applet_type) {
-	case APPLET_BONOBO: {
-		PanelAppletToLoad *applet;
+	applet = g_new0 (PanelAppletToLoad, 1);
 
-		applet = g_new0 (PanelAppletToLoad, 1);
+	applet->type            = applet_type;
+	applet->panel_widget    = panel_widget;
+	applet->position        = position;
+	applet->unique_id       = g_strdup (unique_id);
+	applet->destroy_handler =
+			g_signal_connect (panel_widget, "destroy",
+					  G_CALLBACK (panel_destroyed_while_loading),
+					  applet);
 
-		applet->panel_widget    = panel_widget;
-		applet->position        = position;
-		applet->unique_id       = g_strdup (unique_id);
-		applet->destroy_handler =
-				g_signal_connect (panel_widget, "destroy",
-						  G_CALLBACK (panel_destroyed_while_loading),
-						  applet);
-
-		if (!panel_applets_to_load)
-			g_idle_add (panel_applet_load_idle_handler, NULL);
-
-		panel_applets_to_load = g_slist_prepend (panel_applets_to_load, applet);
-		}
-		break;
-	case APPLET_DRAWER:
-		drawer_load_from_gconf (panel_widget, position, unique_id);
-		break;
-	case APPLET_MENU:
-		menu_load_from_gconf (panel_widget, position, unique_id);
-		break;
-	case APPLET_LAUNCHER:
-		launcher_load_from_gconf (panel_widget, position, unique_id);
-		break;
-	case APPLET_LOGOUT:
-		load_logout_applet (panel_widget, position, TRUE, unique_id);
-		break;
-	case APPLET_LOCK:
-		load_lock_applet (panel_widget, position, TRUE, unique_id);
-		break;
-	default:
-		break;
-	}
+	panel_applets_to_load = g_slist_prepend (panel_applets_to_load, applet);
 }
 
 static void
@@ -898,11 +908,29 @@ panel_applet_load_list (AppletType type)
 	panel_g_slist_deep_free (id_list);
 }
 
+static int
+panel_applet_compare (const PanelAppletToLoad *a,
+		      const PanelAppletToLoad *b)
+{
+	if (a->panel_widget != b->panel_widget)
+		return a->panel_widget - b->panel_widget;
+	else
+		return a->position - b->position;
+}
+
 void
 panel_applet_load_applets_from_gconf (void)
 {
 	panel_applet_load_list (APPLET_BONOBO);
 	panel_applet_load_list (APPLET_EMPTY);
+
+	if (!panel_applets_to_load)
+		return;
+
+	panel_applets_to_load = g_slist_sort (panel_applets_to_load,
+					      (GCompareFunc) panel_applet_compare);
+
+	g_idle_add (panel_applet_load_idle_handler, NULL);
 }
 
 static gboolean
@@ -960,7 +988,7 @@ panel_applet_save_position (AppletInfo *applet_info,
 	gconf_client_set_bool (client, temp_key, right_stick, NULL);
 
 	position = panel_applet_get_position (applet_info);
-	if (right_stick)
+	if (right_stick && !PANEL_WIDGET (applet_info->widget->parent)->packed)
 		position = PANEL_WIDGET (applet_info->widget->parent)->size - position;
 
 	temp_key = panel_applet_get_full_gconf_key (
@@ -1172,8 +1200,6 @@ panel_applet_register (GtkWidget      *applet,
 
 	if (type != APPLET_BONOBO)
 		gtk_widget_grab_focus (applet);
-	else
-		gtk_widget_child_focus (applet, GTK_DIR_TAB_FORWARD);
 
 	return info;
 }
