@@ -35,6 +35,7 @@
 #include "gnome-run.h"
 #include "multiscreen-stuff.h"
 #include "panel-marshal.h"
+#include "panel-stock-icons.h"
 
 #define ICON_SIZE 20
 #define FOOBAR_MENU_FLAGS (MAIN_MENU_SYSTEM | MAIN_MENU_KDE_SUB | MAIN_MENU_DISTRIBUTION_SUB)
@@ -54,10 +55,6 @@ static gboolean foobar_leave_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
 static gboolean foobar_enter_notify	(GtkWidget *widget,
 					 GdkEventCrossing *event);
-static gboolean foobar_key_press	(GtkWidget *widget,
-					 GdkEventKey *event);
-static void foobar_widget_move_focus_out   (FoobarWidget *foo);
-static void foobar_widget_move_focus_out   (FoobarWidget *foo);
 static void append_task_menu (FoobarWidget *foo, GtkMenuShell *menu_bar);
 static void setup_task_menu (FoobarWidget *foo);
 
@@ -65,13 +62,6 @@ static GList *foobars = NULL;
 
 static GtkWindowClass *foobar_widget_parent_class = NULL;
 
-enum {
-	MOVE_FOCUS_OUT_SIGNAL,
-	WIDGET_LAST_SIGNAL
-};
-
-static guint foobar_widget_signals[WIDGET_LAST_SIGNAL] = { 0 };
-
 GType
 foobar_widget_get_type (void)
 {
@@ -103,7 +93,6 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-	GtkBindingSet *binding_set;
 
 	object_class->destroy = foobar_widget_destroy;
 
@@ -111,9 +100,6 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 	widget_class->size_allocate = foobar_widget_size_allocate;
 	widget_class->enter_notify_event = foobar_enter_notify;
 	widget_class->leave_notify_event = foobar_leave_notify;
-	widget_class->key_press_event = foobar_key_press;
-
-	klass->move_focus_out = foobar_widget_move_focus_out;
 
 	gtk_rc_parse_string ("style \"panel-foobar-menubar-style\"\n"
 			     "{\n"
@@ -121,64 +107,6 @@ foobar_widget_class_init (FoobarWidgetClass *klass)
 			     "GtkMenuBar::internal-padding = 0\n"
 			     "}\n"
 			     "widget \"*.panel-foobar-menubar\" style \"panel-foobar-menubar-style\"");
-
-	foobar_widget_signals[MOVE_FOCUS_OUT_SIGNAL] =
-		g_signal_new	("move_focus_out",
-				G_TYPE_FROM_CLASS (object_class),
-				G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-				G_STRUCT_OFFSET (FoobarWidgetClass, move_focus_out),
-				NULL, NULL,
-                                panel_marshal_VOID__VOID,
-				G_TYPE_NONE,
-				0);
-
-	binding_set = gtk_binding_set_by_class (object_class);
-	gtk_binding_entry_add_signal (binding_set,
-                                      GDK_Tab, GDK_CONTROL_MASK,
-                                      "move_focus_out", 0);
-	gtk_binding_entry_add_signal (binding_set,
-                                      GDK_KP_Tab, GDK_CONTROL_MASK,
-                                      "move_focus_out", 0);
-
-
-}
-
-static GtkWidget *
-pixmap_menu_item_new (const char *text, const char *try_file, gboolean force_image)
-{
-	GtkWidget *item;
-	GtkWidget *label;
-
-	item = gtk_image_menu_item_new ();
-
-	panel_load_menu_image_deferred (item, try_file, NULL /* fallback */,
-					force_image);
-
-	if (text) {
-		label = gtk_label_new (text);
-		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-		gtk_container_add (GTK_CONTAINER (item), label);
-	}
-
-	return item;
-}
-
-static gboolean
-foobar_key_press (GtkWidget *widget, GdkEventKey *event)
-{
- 	FoobarWidget *foobar;
-	PanelWidget *panel;
-
-	g_return_val_if_fail (FOOBAR_IS_WIDGET (widget), FALSE);
-
-	foobar = FOOBAR_WIDGET (widget);
-
-	g_return_val_if_fail (PANEL_IS_WIDGET (foobar->panel), FALSE);
-
-	panel = PANEL_WIDGET (foobar->panel);
-
-	panel_widget_save_key_event (panel, event);
-	return GTK_WIDGET_CLASS (foobar_widget_parent_class)->key_press_event (widget, event);
 }
 
 static gboolean
@@ -203,6 +131,16 @@ foobar_enter_notify (GtkWidget *widget,
 	return FALSE;
 }
 
+static void
+foobar_screenshot (GtkWidget *widget, gpointer data) 
+{
+	char *argv[2] = {"gnome-panel-screenshot", NULL};
+
+	if (gnome_execute_async (g_get_home_dir (), 1, argv) < 0)
+		panel_error_dialog ("cannot_exec_gnome-panel-screenshot",
+				    _("Cannot execute gnome-panel-screenshot"));
+}
+
 static void
 foobar_search (GtkWidget *widget,
 	       gpointer   data)
@@ -221,8 +159,9 @@ append_actions_menu (GtkWidget *menu_bar)
 
 	menu = panel_menu_new ();
 
-	item = pixmap_menu_item_new (_("Run Program..."), "gnome-run.png",
-				     FALSE /* force_image */);
+	item = stock_menu_item_new (_("Run Program..."),
+				    PANEL_STOCK_RUN,
+				    FALSE);
 	gtk_tooltips_set_tip (panel_tooltips, item,
 			      _("Run applications, if you know the "
 				"correct command to type in"),
@@ -230,11 +169,12 @@ append_actions_menu (GtkWidget *menu_bar)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	g_signal_connect (G_OBJECT (item), "activate",
 			  G_CALLBACK (show_run_dialog), 0);
-	setup_internal_applet_drag (item, "RUN:NEW");
 
 	if (panel_is_program_in_path  ("gnome-search-tool")) {
-		item = pixmap_menu_item_new (
-				_("Search for Files..."), "gnome-searchtool.png", FALSE);
+		item = stock_menu_item_new (
+				_("Search for Files..."),
+				PANEL_STOCK_SEARCHTOOL,
+				FALSE);
 
 		gtk_tooltips_set_tip (panel_tooltips, item,
 				      _("Find files, folders, and documents "
@@ -246,23 +186,38 @@ append_actions_menu (GtkWidget *menu_bar)
 				  G_CALLBACK (foobar_search), 0);
 	}
 
+	if (panel_is_program_in_path ("gnome-panel-screenshot")) {
+		item = stock_menu_item_new (_("Screenshot..."),
+					    PANEL_STOCK_SCREENSHOT,
+					    FALSE);
+		gtk_tooltips_set_tip (panel_tooltips, item,
+			      	      _("Take a screenshot of your desktop"),
+			              NULL);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+        	g_signal_connect (G_OBJECT (item), "activate",
+			  	  G_CALLBACK (foobar_screenshot), 0);	 
+	}
+
+	item = gtk_separator_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	if (panel_is_program_in_path  ("xscreensaver")) {
-		item = pixmap_menu_item_new (_("Lock Display"), 
-					     "gnome-lockscreen.png",
-					     FALSE /* force_image */);
+		item = stock_menu_item_new (_("Lock Screen"), 
+					    PANEL_STOCK_LOCKSCREEN, 
+					    FALSE);
 		gtk_tooltips_set_tip (panel_tooltips, item,
 				      _("Protect your computer from "
 					"unauthorized use"),
 				      NULL);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-		g_signal_connect (G_OBJECT (item), "activate",
-				  G_CALLBACK (panel_lock), 0);
+		g_signal_connect (item, "activate",
+				  G_CALLBACK (panel_lock), NULL);
 		setup_internal_applet_drag(item, "LOCK:NEW");
 	}
 
-	item = pixmap_menu_item_new (_("Log Out"), "gnome-term-night.png",
-				     FALSE /* force_image */);
+	item = stock_menu_item_new (_("Log Out"),
+				    PANEL_STOCK_LOGOUT,
+				    FALSE);
 	gtk_tooltips_set_tip (panel_tooltips, item,
 			      _("Quit from the GNOME desktop"),
 			      NULL);
@@ -314,14 +269,16 @@ foobar_widget_realize (GtkWidget *w)
 
 
 static void
-programs_menu_to_display (GtkWidget *menu)
+programs_menu_to_display (GtkWidget    *menu,
+			  FoobarWidget *foo)
 {
 	if (menu_need_reread (menu)) {
 		while (GTK_MENU_SHELL (menu)->children)
 			gtk_widget_destroy (GTK_MENU_SHELL (menu)->children->data);
 
-		create_root_menu (menu, TRUE, FOOBAR_MENU_FLAGS,
-				  FALSE, FALSE /* run_item */);
+		create_root_menu (
+			menu, PANEL_WIDGET (foo->panel),
+			TRUE, FOOBAR_MENU_FLAGS, FALSE, FALSE);
 	}
 }
 
@@ -344,6 +301,13 @@ set_the_task_submenu (FoobarWidget *foo, GtkWidget *item)
 static void
 focus_window (GtkWidget *w, WnckWindow *window)
 {
+	WnckWorkspace* space;
+
+	/* Make sure that the current workspace is the same as the app'
+	 * Same behaviour as GNOME 1.4 */
+	space = wnck_window_get_workspace (window);
+	wnck_workspace_activate (space);
+
 	if (wnck_window_is_minimized (window)) 
 		wnck_window_unminimize (window);
 
@@ -360,7 +324,7 @@ get_default_image (void)
 	if ( ! looked) {
 		pixbuf = panel_make_menu_icon ("gnome-tasklist.png",
 					       /* evil fallback huh? */
-					       "apple-red.png",
+					       "gnome-gmenu.png",
 					       20 /* size */,
 					       NULL /* long_operation */);
 
@@ -379,7 +343,7 @@ add_window (WnckWindow *window, FoobarWidget *foo)
 	GtkWidget *image = NULL;
 	GdkPixbuf *pb;
 	const char *name;
-	WnckScreen *screen = wnck_screen_get (0 /* FIXME screen number */);
+	WnckScreen *screen = wnck_screen_get_default ();
 	WnckWorkspace *wspace = wnck_screen_get_active_workspace (screen);
 
 	g_assert (foo->windows != NULL);
@@ -459,7 +423,7 @@ create_task_menu (GtkWidget *w, gpointer data)
 	FoobarWidget *foo = FOOBAR_WIDGET (data);
 	GList *list;
 	GtkWidget *separator;
-	WnckScreen *screen = wnck_screen_get (0 /* FIXME screen number */);
+	WnckScreen *screen = wnck_screen_get_default ();
 	GList *windows = wnck_screen_get_windows (screen);
 
 	/* g_message ("creating..."); */
@@ -504,46 +468,45 @@ destroy_task_menu (GtkWidget *w, gpointer data)
 }
 
 static void
-set_das_pixmap (FoobarWidget *foo, WnckWindow *window)
+set_das_pixmap (FoobarWidget *foo,
+		WnckWindow   *window)
 {
-	GdkPixbuf *pb;
-	if ( ! GTK_WIDGET_REALIZED (foo))
-		return;
+	GdkPixbuf *pixbuf = NULL;
 
-	if (foo->task_image != NULL)
-		gtk_widget_destroy (GTK_WIDGET (foo->task_image));
-	foo->task_image = NULL;
+	if (!GTK_WIDGET_REALIZED (foo))
+		return;
 
 	foo->icon_window = window;
 
-	pb = NULL;
-	if (window != NULL)
-		pb = wnck_window_get_mini_icon (window);
-	if (pb == NULL)
-		pb = get_default_image ();
+	if (window)
+		pixbuf = wnck_window_get_mini_icon (window);
 
-	if (pb != NULL) {
+	if (!pixbuf)
+		pixbuf = get_default_image ();
+
+	if (pixbuf) {
 		double pix_x, pix_y;
-		pix_x = gdk_pixbuf_get_width (pb);
-		pix_y = gdk_pixbuf_get_height (pb);
-		if (pix_x > ICON_SIZE || pix_y > ICON_SIZE) {
-			double greatest;
+
+		pix_x = gdk_pixbuf_get_width (pixbuf);
+		pix_y = gdk_pixbuf_get_height (pixbuf);
+
+		if (pix_x <= ICON_SIZE && pix_y <= ICON_SIZE) 
+			gtk_image_set_from_pixbuf (
+				GTK_IMAGE (foo->task_image), pixbuf);
+		else {
 			GdkPixbuf *scaled;
+			double     greatest;
 
 			greatest = pix_x > pix_y ? pix_x : pix_y;
-			scaled = gdk_pixbuf_scale_simple (pb,
-							  (ICON_SIZE / greatest) * pix_x,
-							  (ICON_SIZE / greatest) * pix_y,
-							  GDK_INTERP_BILINEAR);
-			foo->task_image = gtk_image_new_from_pixbuf (scaled);
-			g_object_unref (G_OBJECT (scaled));
-		} else {
-			foo->task_image = gtk_image_new_from_pixbuf (pb);
+			scaled = gdk_pixbuf_scale_simple (
+					pixbuf,
+					(ICON_SIZE / greatest) * pix_x,
+					(ICON_SIZE / greatest) * pix_y,
+					GDK_INTERP_BILINEAR);
+			gtk_image_set_from_pixbuf (
+				GTK_IMAGE (foo->task_image), scaled);
+			g_object_unref (scaled);
 		}
-		gtk_widget_show (foo->task_image);
-
-		gtk_container_add (GTK_CONTAINER (foo->task_bin),
-				   GTK_WIDGET (foo->task_image));
 	}
 }
 
@@ -558,6 +521,10 @@ append_task_menu (FoobarWidget *foo, GtkMenuShell *menu_bar)
 	gtk_widget_show (foo->task_bin);
 	gtk_container_add (GTK_CONTAINER (foo->task_item), foo->task_bin);
 
+	foo->task_image = gtk_image_new ();
+	gtk_widget_show (foo->task_image);
+	gtk_container_add (GTK_CONTAINER (foo->task_bin), foo->task_image);
+
 	gtk_menu_shell_append (menu_bar, foo->task_item);
 
 	panel_stretch_events_to_toplevel (
@@ -639,7 +606,7 @@ setup_task_menu (FoobarWidget *foo)
 
 	set_the_task_submenu (foo, foo->task_item);
 
-	screen = wnck_screen_get (0 /* FIXME screen number */);
+	screen = wnck_screen_get_default ();
 
 	/* setup the pixmap to the focused task */
 	windows = wnck_screen_get_windows (screen);
@@ -684,6 +651,7 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *align;
+	GtkWidget *image;
 	char      *path;
 
 	window = GTK_WINDOW (foo);
@@ -709,15 +677,17 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	g_signal_connect (G_OBJECT (foo), "delete_event",
 			  G_CALLBACK (gtk_true), NULL);
 
-	gtk_window_move (GTK_WINDOW (foo),
-			 multiscreen_x (foo->screen),
-			 multiscreen_y (foo->screen));
-	g_object_set (G_OBJECT (foo),
-		      "width_request", (int)multiscreen_width (foo->screen),
-		      NULL);
+	/* panel widget */
+	foo->panel = panel_widget_new (NULL, FALSE, GTK_ORIENTATION_HORIZONTAL,
+				       PANEL_SIZE_X_SMALL, PANEL_BACK_NONE,
+				       NULL, FALSE, FALSE, FALSE, NULL);
+	PANEL_WIDGET (foo->panel)->panel_parent = GTK_WIDGET (foo);
+	PANEL_WIDGET (foo->panel)->drop_widget = GTK_WIDGET (foo);
+	panel_set_atk_name_desc (foo->panel, _("Menu Panel"), _("GNOME Menu Panel"));
 
 	foo->ebox = gtk_event_box_new ();
 	foo->hbox = gtk_hbox_new (FALSE, 0);
+	gtk_widget_set_direction (foo->hbox, GTK_TEXT_DIR_LTR);
 	gtk_container_add(GTK_CONTAINER(foo->ebox), foo->hbox);
 
 	path = panel_pixmap_discovery ("panel-corner-left.png", FALSE /* fallback */);
@@ -732,18 +702,21 @@ foobar_widget_instance_init (FoobarWidget *foo)
 	menu_bar = gtk_menu_bar_new ();	
 	gtk_widget_set_name (menu_bar,
 			     "panel-foobar-menubar");
-	
-	menuitem = pixmap_menu_item_new (_("Applications"),
-					 "gnome-logo-icon-transparent.png",
-					 TRUE /* force_image */);
 
-	menu = create_root_menu (NULL, TRUE, FOOBAR_MENU_FLAGS,
-				 FALSE, FALSE /* run_item */);
+	menuitem = gtk_image_menu_item_new_with_label (_("Applications"));
+	image = gtk_image_new_from_stock (
+			PANEL_STOCK_GNOME_LOGO,
+			panel_foobar_icon_get_size ()),
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image);
+
+	menu = create_root_menu (
+			NULL, PANEL_WIDGET (foo->panel),
+			TRUE, FOOBAR_MENU_FLAGS, FALSE, FALSE);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu_bar), menuitem);
 	g_signal_connect (G_OBJECT (menu), "show",
 			  G_CALLBACK (programs_menu_to_display),
-			  NULL);
+			  foo);
 	foo->programs = menu;
 
 	/* Strech the applications menu to the corner */
@@ -754,20 +727,8 @@ foobar_widget_instance_init (FoobarWidget *foo)
 
 	gtk_box_pack_start (GTK_BOX (foo->hbox), menu_bar, FALSE, FALSE, 0);
 	
-	
-	/* panel widget */
-	foo->panel = panel_widget_new (NULL, FALSE, GTK_ORIENTATION_HORIZONTAL,
-				       PANEL_SIZE_X_SMALL, PANEL_BACK_NONE,
-				       NULL, FALSE, FALSE, FALSE, NULL);
-	PANEL_WIDGET (foo->panel)->panel_parent = GTK_WIDGET (foo);
-	PANEL_WIDGET (foo->panel)->drop_widget = GTK_WIDGET (foo);
-
 	gtk_container_add (GTK_CONTAINER (foo->hbox), foo->panel);
 
-	g_object_set_data (G_OBJECT (menu_bar), "menu_panel", foo->panel);
-
-	add_atk_name_desc (foo->panel, _("Menu Panel"), _("GNOME Menu Panel"));
-
 	path = panel_pixmap_discovery ("panel-corner-right.png", FALSE /* fallback */);
 	if (path != NULL) {
 		bufmap = gtk_image_new_from_file (path);
@@ -847,28 +808,28 @@ foobar_widget_size_allocate (GtkWidget *w, GtkAllocation *alloc)
 }
 
 GtkWidget *
-foobar_widget_new (const char *panel_id, int screen)
+foobar_widget_new (const char *panel_id,
+		   int         screen)
 {
 	FoobarWidget *foo;
 
-	g_return_val_if_fail (screen >=0, NULL);
+	g_return_val_if_fail (screen >= 0, NULL);
 
 	if (foobar_widget_exists (screen))
 		return NULL;
 
-	foo = g_object_new (FOOBAR_TYPE_WIDGET, NULL);
+	foo = g_object_new (FOOBAR_TYPE_WIDGET,
+			    "width_request", multiscreen_width (screen),
+			    NULL);
 
 	if (panel_id)
 		panel_widget_set_id (PANEL_WIDGET (foo->panel), panel_id);
 
-	foo->screen = screen;
+	foo->screen  = screen;
 
 	gtk_window_move (GTK_WINDOW (foo),
-			 multiscreen_x (foo->screen),
-			 multiscreen_y (foo->screen));
-	g_object_set (G_OBJECT (foo),
-		      "width_request", (int)multiscreen_width (foo->screen),
-		      NULL);
+			 multiscreen_x (screen),
+			 multiscreen_y (screen));
 
 	foobars = g_list_prepend (foobars, foo);
 
@@ -878,14 +839,17 @@ foobar_widget_new (const char *panel_id, int screen)
 gboolean
 foobar_widget_exists (int screen)
 {
-	GList *li;
+	GList *l;
 
-	for (li = foobars; li != NULL; li = li->next) {
-		FoobarWidget *foo = li->data;
+	g_return_val_if_fail (screen  >= 0, 0);
+
+	for (l = foobars; l; l = l->next) {
+		FoobarWidget *foo = l->data;
 
 		if (foo->screen == screen)
 			return TRUE;
 	}
+
 	return FALSE;
 }
 
@@ -905,19 +869,20 @@ foobar_widget_force_menu_remake (void)
 	}
 }
 
-gint
+int
 foobar_widget_get_height (int screen)
 {
-	GList *li;
+	GList *l;
 
-	g_return_val_if_fail (screen >= 0, 0);
+	g_return_val_if_fail (screen  >= 0, 0);
 
-	for (li = foobars; li != NULL; li = li->next) {
-		FoobarWidget *foo = FOOBAR_WIDGET(li->data);
+	for (l = foobars; l; l = l->next) {
+		FoobarWidget *foo = FOOBAR_WIDGET (l->data);
 
-		if (foo->screen == screen)
+		if (foo->screen  == screen)
 			return GTK_WIDGET (foo)->allocation.height;
 	}
+
 	return 0; 
 }
 
@@ -1025,9 +990,3 @@ foobar_widget_redo_window(FoobarWidget *foo)
 
 	gtk_widget_map(widget);
 }
-
-static void
-foobar_widget_move_focus_out (FoobarWidget *foobar)
-{
- 	panel_widget_focus (PANEL_WIDGET (foobar->panel));
-}
