@@ -16,7 +16,6 @@ struct _MenuFinfo {
 	char *menudir;
 	gboolean launcher_add;
 	char *dir_name;
-	char *pixmap_name;	
 	gboolean fake_menu;
 	FileRec *fr;
 };
@@ -42,6 +41,7 @@ struct _FileRec {
 	char *fullname;
 	char *name_collate_key;
 	char *icon;
+	char *exec;
 	char *tryexec_path;
 	DirRec *parent;
 	time_t mtime;
@@ -52,7 +52,6 @@ struct _DirRec {
 	FileRec frec;
 	time_t ditemmtime;
 	time_t ditemlast_stat;
-	gboolean force_reread;
 	GSList *tryexecs;
 	GSList *recs; /*records for directories*/
 	GSList *mfl;  /*records of menus using this record*/
